@@ -1067,7 +1067,9 @@ def ReadESNOutput(filepath: str,
 
 ###########################################################################################################
 import matplotlib.pyplot as plt
+import seaborn as sns
 
+clrs = sns.color_palette()
 
 def plot_activation_arg_distribution(esn,
                                     style_dict,
@@ -1077,9 +1079,19 @@ def plot_activation_arg_distribution(esn,
 
     """
     Plots activation argument distribution from compute_activation_arg_distribution method in core.py
+    INPUT:
+        esn         - ESN object
+        style_dict  - dict specifying plot parameters
+        bins_input  - bins to use for computing the distribution of Win@u (inputs)
+        bins_res    - bins to use for computing the distribution of Wres@x (reservoir states)
+        bins_fb     - bins to use for computing the distribution of Wfb@y (feedbacks)
+        
+    RETURN:
+        fig - figure 
+        axs - axes
     """
-
-    # Style
+    # Read Style
+    #-----------------
     base_size1,base_size2 = style_dict["base_size1"], style_dict["base_size2"]
     fs_label,fs_tick = style_dict["fs_label"],style_dict["fs_tick"]
     lw = style_dict["lw"]
@@ -1090,6 +1102,7 @@ def plot_activation_arg_distribution(esn,
     xlabels_tanh = [r'$\tanh($'+label+r')' for label in xlabels]
 
     # Plot
+    #-----------------
     fig,axs = plt.subplots(figsize=(base_size1*4,base_size2),ncols=4,sharey=True,nrows=2)
 
     hists_train, bins_train = esn.compute_activation_arg_distribution(40,40,40,phase='train')
@@ -1123,4 +1136,76 @@ def plot_activation_arg_distribution(esn,
     axs[0,0].legend(loc="lower left",bbox_to_anchor=(0,.68),fontsize=fs_label)
     plt.subplots_adjust(wspace=0.15,hspace=0.3)
 
-    return fig, axs
\ No newline at end of file
+    return fig, axs
+
+#--------------------------------------------------------------------------
+def plot_esn_predictions(esn,y_pred,style_dict,modes=None,phase='test'):
+    """
+    Plots ESN prediction from specified phase. 
+    INPUT:
+        esn        - ESN object
+        y_pred     - ESN prediction  
+        style_dict - dict specifying plot parameters
+        modes      - list specifying which modes of y_pred will be plotted
+        phase      - str indicating for which phase the distributions should be computed: 'train', 'test', 'validation'
+    
+    RETURN:
+        fig - figure 
+        axs - axes
+    """
+    
+    # Read Style 
+    #-----------------
+    base_size1,base_size2 = style_dict["base_size1"], style_dict["base_size2"]
+    fs_label,fs_tick = style_dict["fs_label"],style_dict["fs_tick"]
+    lw = style_dict["lw"]
+    ylim = style_dict["ylim"]
+ 
+    if modes == None:
+        modes = range(esn.n_output)
+        
+    try:
+        ylabels = style_dict["ylabels"]
+    except KeyError:
+        ylabels = [r'$a_{'+f'{ii+1}'+ r'}$'for ii in modes]
+    
+    
+    if phase == 'train':
+        y_gt = esn.y_train[self.transientTime:]
+    elif phase == 'test':
+        y_gt = esn.y_test
+    elif phase == 'validation':
+        y_gt = esn.y_val
+    
+    nt = y_gt.shape[0]
+        
+    # Plot
+    #-----------------
+    fig,axs = plt.subplots(figsize = (base_size1,base_size2*len(modes)), nrows = len(modes), sharex = True)
+
+    for ii,imode in enumerate(modes):
+        axs[ii].plot(range(nt),
+                     y_gt[:,imode], 
+                     label = 'GT',
+                     color = clrs[0],
+                     linewidth = linewidth)
+        axs[ii].plot(range(nt),
+                     y_pred[:,imode], 
+                     label = 'ESN',linestyle="dashed",
+                     color = clrs[1],
+                     linewidth = linewidth)
+
+
+        axs[ii].set_ylabel(ylabels[ii], fontsize = fs_label, rotation = 0, labelpad = 17)
+        axs[ii].set_ylim(ylim)
+
+    # tidy up
+    for iax in axs:
+        iax.tick_params(axis="x", labelsize = fs_ticks)
+        iax.tick_params(axis="y", labelsize = fs_ticks)
+
+    axs[-1].set_xlabel('time step',fontsize = fs_label);
+
+    return fig,axs
+
+#--------------------------------------------------------------------------
\ No newline at end of file
